@@ -145,7 +145,7 @@ void ProfileManager::loadExistingProfilesList()
 		}
 		else
 		{
-			qWarning("Profile %s is unadmissible.", qPrintable(profileName));
+			qWarning("Skipped the profile %s.", qPrintable(profileName));
 		}
 	}
 
