@@ -18,10 +18,6 @@
 #include <cstdio>
 #include <cmath>
 
-#ifdef YF_ENABLE_CHECKS
-	#include <boost/static_assert.hpp>
-#endif
-
 #include <yf/defs.hpp>
 
 #include <yf/time/time.hpp>
@@ -33,9 +29,7 @@ namespace yf
 	{
 		#ifdef OS_WINDOWS
 			precise_time_t mt;
-			#ifdef YF_ENABLE_CHECKS
-				BOOST_STATIC_ASSERT(sizeof(precise_time_t) == sizeof (LARGE_INTEGER));
-			#endif
+			static_assert(sizeof(precise_time_t) == sizeof (LARGE_INTEGER));
 			QueryPerformanceCounter((LARGE_INTEGER*)&mt);
 			return mt;
 		#elif defined(OS_LINUX)
